OC.L10N.register(
    "news",
    {
    "Request failed, network connection unavailable!" : "Неуспешна заявка, няма налична мрежова връзка!",
    "Request unauthorized. Are you logged in?" : "Заявката не е упълномощена. Вписан ли сте?",
    "Request forbidden. Are you an admin?" : "Достъп е отказан. Администратор ли сте?",
    "Token expired or app not enabled! Reload the page!" : "Изтекла парола или приложението не е активирано! Презаредете страницата!",
    "Internal server error! Please check your data/nextcloud.log file for additional information!" : "Вътрешно сървърна грешка! За допълнителна информация проверете файла data/nextcloud.log !",
    "Request failed, Nextcloud is in currently in maintenance mode!" : "Заявка се провали, Nextcloud в момента е в режим на поддръжка!",
    "News" : "Новини",
    "An RSS/Atom feed reader" : "Четец за RSS/Atom емисии",
    "Use system cron for updates" : "Използване на системния cron за актуализации",
    "Purge interval" : "Интервал за изтриване",
    "Maximum read count per feed" : "Максимален брой прочитания на емисия",
    "Maximum redirects" : "Максимален брой пренасочвания",
    "Feed fetcher timeout" : "Максимално време за изчакване",
    "Saved" : "Запазено",
    "Download" : "Изтегли",
    "Close" : "Затваряне",
    "No articles available" : "Няма статии",
    "No unread articles available" : "Няма непрочетени статии",
    "Open website" : "Отвори интернет станица",
    "Star article" : "Означи със звезда",
    "Unstar article" : "Премахни означаването със звезда",
    "Keep article unread" : "Постоянното означаване като непрочетена",
    "Remove keep article unread" : "Премахни постоянното означаване като непрочетена",
    "by" : "от",
    "from" : "от",
    "Play audio" : "Стартирай аудио",
    "Download audio" : "Изтегли аудио",
    "Download video" : "Изтегли видео",
    "Keyboard shortcut" : "Клавишни комбинации",
    "Description" : "Описание",
    "right" : "дясно",
    "Jump to next article" : "Отиди на следващата статия",
    "left" : "ляво",
    "Jump to previous article" : "Отиди на предната статия",
    "Toggle star article" : "Превключи означаването със звезда",
    "Star article and jump to next one" : "Маркирай като любим и се премести на следващата статия",
    "Toggle keep current article unread" : "Промяна запазва статуса на статията като непрочетена",
    "Open article in new tab" : "Отвори статия в нов таб",
    "Toggle expand article in compact view" : "Промяна разширява статията в комапктен изглед",
    "Refresh" : "Опресняване",
    "Load next feed" : "Следваща емисия",
    "Load previous feed" : "Предишна емисия",
    "Load next folder" : "Зареди следваща папка",
    "Load previous folder" : "Зареди предна папка",
    "Scroll to active navigation entry" : "Превъртете до активен навигационен бутон",
    "Focus search field" : "Фокусирай полето за търсене",
    "Mark current article's feed/folder read" : "Означи статиите от текущият поток/папка като прочетени",
    "Ajax or webcron mode detected! Your feeds will not be updated!" : "Засечен е Ajax или webcron режим! Емисиите няма да бъдат актуализирани!",
    "How to set up the operating system cron" : "Как се настройва работещия системен cron",
    "Subscribe" : "Абониране",
    "Web address" : "Уеб адрес",
    "Feed exists already!" : "Емисията вече съществува!",
    "Folder" : "Папка",
    "No folder" : "Няма папка",
    "New folder" : "Нова папка",
    "Folder name" : "Име на папката",
    "Go back" : "Назад",
    "Folder exists already!" : "Папката вече съществува!",
    "Credentials" : "Потребител и парола",
    "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!" : "HTTP Basic Auth credentials (потребителското име и паролата) ще бъдат записани в некриптиран вид! Те ще бъдат видими за всеки с достъп до сървъра!",
    "Username" : "Потребител",
    "Password" : "Парола",
    "New Folder" : "Нова папка",
    "Create" : "Създай",
    "Explore" : "Проучи",
    "Update failed more than 50 times" : "Неуспешна актуализация повече от 50 пъти",
    "Deleted feed" : "Изтрита емисия",
    "Undo delete feed" : "Върни изтритата емисия",
    "Rename" : "Преименувай",
    "Menu" : "Меню",
    "Mark read" : "Означи като прочетена",
    "Unpin from top" : "Откачи от най-отгоре",
    "Pin to top" : "Закачи най-отгоре",
    "Newest first" : "Най-нов",
    "Oldest first" : "Най-стар",
    "Default order" : "Стандартна подредба",
    "Enable full text" : "Показвай целия текст",
    "Disable full text" : "Не показвай целия текст",
    "Open feed URL" : "Отвори URL на емисията",
    "Delete" : "Изтрий",
    "Dismiss" : "Затвори",
    "Collapse" : "Намали",
    "Deleted folder" : "Изтрий папка",
    "Undo delete folder" : "Върни изтритата папка",
    "Starred" : "Със звезда",
    "Unread articles" : "Непрочетени статии",
    "All articles" : "Всички статии",
    "Settings" : "Настройки",
    "Disable mark read through scrolling" : "Без означаване като \"Прочетена\" след скролиране",
    "Compact view" : "Компактен изглед",
    "Expand articles on key navigation" : "Разшири статиите от ключовата навигация",
    "Show all articles" : "Показвай всички статии",
    "Reverse ordering (oldest on top)" : "Обратен ред (най-старите отгоре)",
    "Subscriptions (OPML)" : "Абонаменти (OPML)",
    "Import" : "Внасяне",
    "Export" : "Изнасяне",
    "Error when importing: File does not contain valid OPML" : "Грешка при внасяне: файлът не е валиден OPML",
    "Error when importing: OPML is does neither contain feeds nor folders" : "Грешка при внасяне: OPML файлът не съдържа емисии/папки",
    "Unread/Starred Articles" : "Непрочетени/Означени със звезда статии",
    "Error when importing: file does not contain valid JSON" : "Грешка при внасяне: файлът не е валиден JSON",
    "Help" : "Помощ",
    "Keyboard shortcuts" : "Клавишни комбинации",
    "Documentation" : "Документация",
    "Report a bug" : "Докладване за грешка"
},
"nplurals=2; plural=(n != 1);");
